# expetator

A tool for running HPC benchmarks using several type of leverages (DVFS) and low-level monitoring (hardware performance counters, RAPL) mostly on Grid5000.

Documentation is available here: https://expetator.readthedocs.io/

Source code is available here: https://gitlab.irit.fr/sepia-pub/expetator

To install expetator:

	pip3 install expetator
